@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -30,6 +31,10 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
+
 #ifndef YY_YY_GRAMMAR_H_INCLUDED
 # define YY_YY_GRAMMAR_H_INCLUDED
 /* Debug traces.  */
@@ -40,35 +45,44 @@
 extern int yydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    WS = 258,
-    ID = 259,
-    INTERP = 260,
-    FLOAT = 261,
-    INTEGER = 262,
-    BACKREF = 263,
-    FWDREF = 264,
-    REGISTER = 265,
-    TEXT = 266,
-    SHL = 267,
-    SHR = 268,
-    LE = 269,
-    GE = 270,
-    EQ = 271,
-    NE = 272,
-    LOR = 273,
-    LAND = 274,
-    DELIM = 275,
-    DEC2 = 276,
-    INC2 = 277,
-    UMINUS = 278
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    WS = 258,                      /* WS  */
+    ID = 259,                      /* ID  */
+    INTERP = 260,                  /* INTERP  */
+    FLOAT = 261,                   /* FLOAT  */
+    INTEGER = 262,                 /* INTEGER  */
+    BACKREF = 263,                 /* BACKREF  */
+    FWDREF = 264,                  /* FWDREF  */
+    REGISTER = 265,                /* REGISTER  */
+    TEXT = 266,                    /* TEXT  */
+    SHL = 267,                     /* SHL  */
+    SHR = 268,                     /* SHR  */
+    LE = 269,                      /* LE  */
+    GE = 270,                      /* GE  */
+    EQ = 271,                      /* EQ  */
+    NE = 272,                      /* NE  */
+    LOR = 273,                     /* LOR  */
+    LAND = 274,                    /* LAND  */
+    DELIM = 275,                   /* DELIM  */
+    DEC2 = 276,                    /* DEC2  */
+    INC2 = 277,                    /* INC2  */
+    UMINUS = 278                   /* UMINUS  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define WS 258
 #define ID 259
 #define INTERP 260
@@ -93,10 +107,9 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 43 "grammar.y" /* yacc.c:1909  */
+#line 48 "grammar.y"
 
 	int as_token;
 	int64_t as_int;
@@ -108,9 +121,9 @@ union YYSTYPE
 	struct slist *as_list;
 	
 
-#line 112 "grammar.h" /* yacc.c:1909  */
-};
+#line 125 "grammar.h"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -119,6 +132,8 @@ typedef union YYSTYPE YYSTYPE;
 
 extern YYSTYPE yylval;
 
+
 int yyparse (void);
 
+
 #endif /* !YY_YY_GRAMMAR_H_INCLUDED  */
