@@ -1,12 +1,17 @@
 /*
 
-asm6809, a Motorola 6809 cross assembler
-Copyright 2013-2017 Ciaran Anscomb
+Instruction assembly
 
-This program is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation, either version 3 of the License, or (at your
-option) any later version.
+Copyright 2013-2023 Ciaran Anscomb
+
+This file is part of asm6809.
+
+asm6809 is free software: you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 3 of the License, or (at your option)
+any later version.
+
+See COPYING.GPL for redistribution conditions.
 
 */
 
@@ -501,6 +506,14 @@ void instr_stack(struct opcode const *op, struct node const *args, enum reg_id s
 
 	int pbyte = 0;
 	for (int i = 0; i < nargs; i++) {
+		if (node_attr_of(arga[i]) == node_attr_immediate) {
+			struct node *tmp = eval_int(arga[i]);
+			if (tmp) {
+				pbyte |= tmp->data.as_int;
+				node_free(tmp);
+			}
+			continue;
+		}
 		if (node_type_of(arga[i]) != node_type_reg) {
 			error(error_type_syntax, "invalid argument");
 			return;
@@ -583,7 +596,7 @@ void instr_tfm(struct opcode const *op, struct node const *args) {
 		return;
 	}
 
-	int nibble[2];
+	int nibble[2] = { 0, 0 };
 	int type[2];
 	int attr[2];
 	for (int i = 0; i < 2; i++) {
