@@ -1,12 +1,17 @@
 /*
 
-asm6809, a Motorola 6809 cross assembler
-Copyright 2013-2017 Ciaran Anscomb
+Sections
 
-This program is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation, either version 3 of the License, or (at your
-option) any later version.
+Copyright 2013-2023 Ciaran Anscomb
+
+This file is part of asm6809.
+
+asm6809 is free software: you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 3 of the License, or (at your option)
+any later version.
+
+See COPYING.GPL for redistribution conditions.
 
 */
 
@@ -49,7 +54,8 @@ static struct section_span *section_span_new(void) {
 	return new;
 }
 
-static struct section_span *section_span_ref(struct section_span *span) {
+static struct section_span *section_span_ref(struct section_span *span, void *copy_data) {
+	(void)copy_data;
 	if (!span)
 		return NULL;
 	span->ref++;
